Struct memflow::os::module::ModuleInfo
source · #[repr(C)]pub struct ModuleInfo {
pub address: Address,
pub parent_process: Address,
pub base: Address,
pub size: umem,
pub name: ReprCString,
pub path: ReprCString,
pub arch: ArchitectureIdent,
}Expand description
Module information structure
Fields
address: AddressReturns the address of the module header.
Remarks
On Windows this will be the address where the PEB entry is stored.
parent_process: AddressThe base address of the parent process.
Remarks
This field is analog to the ProcessInfo::address field.
base: AddressThe actual base address of this module.
Remarks
The base address is contained in the virtual address range of the process this module belongs to.
size: umemSize of the module
name: ReprCStringName of the module
path: ReprCStringPath of the module
arch: ArchitectureIdentArchitecture of the module
Remarks
Emulated processes often have 2 separate lists of modules, one visible to the emulated
context (e.g. all 32-bit modules in a WoW64 process), and the other for all native modules
needed to support the process emulation. This should be equal to either
ProcessInfo::proc_arch, or ProcessInfo::sys_arch of the parent process.