pub struct MemoryViewVtbl<'cglue_a, CGlueC: 'cglue_a + CGlueObjBase> { /* private fields */ }Expand description
CGlue vtable for trait MemoryView.
This virtual function table contains ABI-safe interface for the given trait.
Implementations
Sourceimpl<'cglue_a, CGlueC: CGlueObjBase> MemoryViewVtbl<'cglue_a, CGlueC>
impl<'cglue_a, CGlueC: CGlueObjBase> MemoryViewVtbl<'cglue_a, CGlueC>
Sourcepub fn read_raw_iter(
&self,
) -> unsafe extern "C" fn(cont: &mut CGlueC, data: ReadRawMemOps<'_, '_, '_, '_>) -> i32
pub fn read_raw_iter( &self, ) -> unsafe extern "C" fn(cont: &mut CGlueC, data: ReadRawMemOps<'_, '_, '_, '_>) -> i32
Getter for read_raw_iter.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn write_raw_iter(
&self,
) -> unsafe extern "C" fn(cont: &mut CGlueC, data: WriteRawMemOps<'_, '_, '_, '_>) -> i32
pub fn write_raw_iter( &self, ) -> unsafe extern "C" fn(cont: &mut CGlueC, data: WriteRawMemOps<'_, '_, '_, '_>) -> i32
Getter for write_raw_iter.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn metadata(
&self,
) -> unsafe extern "C" fn(cont: &CGlueC) -> MemoryViewMetadata
pub fn metadata( &self, ) -> unsafe extern "C" fn(cont: &CGlueC) -> MemoryViewMetadata
Getter for metadata.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn read_iter(
&self,
) -> for<'a, 'b> unsafe extern "C" fn(cont: &mut CGlueC, inp: CIterator<'_, ReadData<'a>>, out: Option<&mut ReadCallback<'b, 'a>>, out_fail: Option<&mut ReadCallback<'b, 'a>>) -> i32
pub fn read_iter( &self, ) -> for<'a, 'b> unsafe extern "C" fn(cont: &mut CGlueC, inp: CIterator<'_, ReadData<'a>>, out: Option<&mut ReadCallback<'b, 'a>>, out_fail: Option<&mut ReadCallback<'b, 'a>>) -> i32
Getter for read_iter.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn read_raw_list(
&self,
) -> unsafe extern "C" fn(cont: &mut CGlueC, data: CSliceMut<'_, ReadData<'_>>) -> i32
pub fn read_raw_list( &self, ) -> unsafe extern "C" fn(cont: &mut CGlueC, data: CSliceMut<'_, ReadData<'_>>) -> i32
Getter for read_raw_list.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn read_raw_into(
&self,
) -> unsafe extern "C" fn(cont: &mut CGlueC, addr: Address, out: CSliceMut<'_, u8>) -> i32
pub fn read_raw_into( &self, ) -> unsafe extern "C" fn(cont: &mut CGlueC, addr: Address, out: CSliceMut<'_, u8>) -> i32
Getter for read_raw_into.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn write_iter(
&self,
) -> for<'a, 'b> unsafe extern "C" fn(cont: &mut CGlueC, inp: CIterator<'_, WriteData<'a>>, out: Option<&mut WriteCallback<'b, 'a>>, out_fail: Option<&mut WriteCallback<'b, 'a>>) -> i32
pub fn write_iter( &self, ) -> for<'a, 'b> unsafe extern "C" fn(cont: &mut CGlueC, inp: CIterator<'_, WriteData<'a>>, out: Option<&mut WriteCallback<'b, 'a>>, out_fail: Option<&mut WriteCallback<'b, 'a>>) -> i32
Getter for write_iter.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.
Sourcepub fn write_raw_list(
&self,
) -> unsafe extern "C" fn(cont: &mut CGlueC, data: CSliceRef<'_, WriteData<'_>>) -> i32
pub fn write_raw_list( &self, ) -> unsafe extern "C" fn(cont: &mut CGlueC, data: CSliceRef<'_, WriteData<'_>>) -> i32
Getter for write_raw_list.
Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.