Struct memflow::mem::virt_mem::virtual_dma::VirtualDma
source · [−]pub struct VirtualDma<T, V, D> { /* private fields */ }Expand description
The VirtualDma struct provides a default implementation to access virtual memory
from user provided PhysicalMemory and VirtualTranslate2 objects.
This struct implements MemoryView and allows the user to access the virtual memory of a process.
Implementations
sourceimpl<T: PhysicalMemory, D: VirtualTranslate3> VirtualDma<T, DirectTranslate, D>
impl<T: PhysicalMemory, D: VirtualTranslate3> VirtualDma<T, DirectTranslate, D>
sourcepub fn new(phys_mem: T, arch: impl Into<ArchitectureObj>, translator: D) -> Self
pub fn new(phys_mem: T, arch: impl Into<ArchitectureObj>, translator: D) -> Self
Constructs a VirtualDma object from user supplied architectures and DTB.
It creates a default VirtualTranslate2 object using the DirectTranslate struct.
If you want to use a cache for translating virtual to physical memory
consider using the VirtualDma::with_vat() function and supply your own VirtualTranslate2 object.
Examples
Constructing a VirtualDma object with a given dtb and using it to read:
use memflow::types::Address;
use memflow::architecture::x86::x64;
use memflow::mem::{PhysicalMemory, VirtualTranslate2, MemoryView, VirtualDma};
use memflow::cglue::Fwd;
fn read(phys_mem: Fwd<&mut impl PhysicalMemory>, vat: &mut impl VirtualTranslate2, dtb: Address, read_addr: Address) {
let arch = x64::ARCH;
let translator = x64::new_translator(dtb);
let mut virt_mem = VirtualDma::new(phys_mem, arch, translator);
let mut addr = 0u64;
virt_mem.read_into(read_addr, &mut addr).unwrap();
println!("addr: {:x}", addr);
}sourceimpl<T: PhysicalMemory, V: VirtualTranslate2, D: VirtualTranslate3> VirtualDma<T, V, D>
impl<T: PhysicalMemory, V: VirtualTranslate2, D: VirtualTranslate3> VirtualDma<T, V, D>
sourcepub fn with_vat(
phys_mem: T,
arch: impl Into<ArchitectureObj>,
translator: D,
vat: V
) -> Self
pub fn with_vat(
phys_mem: T,
arch: impl Into<ArchitectureObj>,
translator: D,
vat: V
) -> Self
This function constructs a VirtualDma instance with a user supplied VirtualTranslate2 object.
It can be used when working with cached virtual to physical translations such as a Tlb.
Examples
Constructing a VirtualDma object with VAT and using it to read:
use memflow::types::Address;
use memflow::architecture::x86::x64;
use memflow::mem::{PhysicalMemory, VirtualTranslate2, MemoryView, VirtualDma};
use memflow::cglue::Fwd;
fn read(phys_mem: Fwd<&mut impl PhysicalMemory>, vat: impl VirtualTranslate2, dtb: Address, read_addr: Address) {
let arch = x64::ARCH;
let translator = x64::new_translator(dtb);
let mut virt_mem = VirtualDma::with_vat(phys_mem, arch, translator, vat);
let mut addr = 0u64;
virt_mem.read_into(read_addr, &mut addr).unwrap();
println!("addr: {:x}", addr);
}sourcepub fn sys_arch(&self) -> ArchitectureObj
pub fn sys_arch(&self) -> ArchitectureObj
Returns the architecture of the system. The system architecture is used for virtual to physical translations.
sourcepub fn proc_arch(&self) -> ArchitectureObj
pub fn proc_arch(&self) -> ArchitectureObj
Returns the architecture of the process for this context. The process architecture is mainly used to determine pointer sizes.
sourcepub fn translator(&self) -> &impl VirtualTranslate3
pub fn translator(&self) -> &impl VirtualTranslate3
Returns the Directory Table Base of this process.
sourcepub fn read_addr(&mut self, addr: Address) -> PartialResult<Address>
pub fn read_addr(&mut self, addr: Address) -> PartialResult<Address>
A wrapper around read_addr64 and read_addr32 that will use the pointer size of this context’s process.
TODO: do this in virt mem
sourcepub fn into_inner(self) -> (T, V)
pub fn into_inner(self) -> (T, V)
Consumes this VirtualDma object, returning the underlying memory and vat objects
pub fn mem_vat_pair(&mut self) -> (&mut T, &mut V)
pub fn phys_mem(&mut self) -> &mut T
pub fn phys_mem_ref(&self) -> &T
pub fn vat(&mut self) -> &mut V