This module contains functions related to the Inventory system for Connectors and Os-Plugins.
All functionality in this module is gated behind plugins feature.
Re-exports
pub use inventory::Inventory;pub use connector::ConnectorArgs;pub use connector::ConnectorDescriptor;pub use connector::ConnectorMiddlewareArgs;pub use connector::LoadableConnector;pub use os::LoadableOs;pub use os::MuOsInstanceArcBox;pub use os::OsArgs;pub use os::OsDescriptor;pub use builder::*;pub use connector::cglue_connectorinstance::*;pub use os::cglue_intoprocessinstance::*;pub use os::cglue_osinstance::*;pub use os::cglue_processinstance::*;pub use logger::*;
Modules
- args
- Connector argument handler.
- builder
- connector
- inventory
- logger
- os
- plugin_
analyzer - This module provides functionality to extract the PluginDescriptorInfo from a binary.
Structs
- LibContext
- Context for a single library.
- Plugin
Descriptor - Target
Info - Target information structure
Constants
- MEMFLOW_
PLUGIN_ VERSION - Exported memflow plugins version
Traits
- Loadable
- Defines a common interface for loadable plugins
Functions
- plugin_
architecture - Returns the plugin architecture appropriate for the current os
- plugin_
extension - Returns the plugin extension appropriate for the current os
- plugin_
file_ type - Returns the plugin file_type appropriate for the current os
- plugins_
path - Returns the path in which memflow plugins are stored.
- wrap
- Wrapper for instantiating object.
- wrap_
with_ input - Wrapper for instantiating object with all needed parameters