#[repr(transparent)]pub struct Pointer<U: Sized, T: ?Sized = ()> {
pub inner: U,
/* private fields */
}Expand description
This type can be used in structs that are being read from the target memory. It holds a phantom type that can be used to describe the proper type of the pointer and to read it in a more convenient way.
This module is a direct adaption of CasualX’s great IntPtr crate.
Generally the generic Type should implement the Pod trait to be read into easily. See here for more information on the Pod trait.
Examples
use memflow::types::Pointer64;
use memflow::mem::MemoryView;
use memflow::dataview::Pod;
#[repr(C)]
#[derive(Clone, Debug, Pod)]
struct Foo {
pub some_value: i64,
}
#[repr(C)]
#[derive(Clone, Debug, Pod)]
struct Bar {
pub foo_ptr: Pointer64<Foo>,
}
fn read_foo_bar(mem: &mut impl MemoryView) {
let bar: Bar = mem.read(0x1234.into()).unwrap();
let foo = bar.foo_ptr.read(mem).unwrap();
println!("value: {}", foo.some_value);
}
use memflow::types::Pointer64;
use memflow::mem::MemoryView;
use memflow::dataview::Pod;
#[repr(C)]
#[derive(Clone, Debug, Pod)]
struct Foo {
pub some_value: i64,
}
#[repr(C)]
#[derive(Clone, Debug, Pod)]
struct Bar {
pub foo_ptr: Pointer64<Foo>,
}
fn read_foo_bar(mem: &mut impl MemoryView) {
let bar: Bar = mem.read(0x1234.into()).unwrap();
let foo = mem.read_ptr(bar.foo_ptr).unwrap();
println!("value: {}", foo.some_value);
}
Fields
inner: UImplementations
sourceimpl<U: PrimitiveAddress, T: ?Sized> Pointer<U, T>
impl<U: PrimitiveAddress, T: ?Sized> Pointer<U, T>
sourcepub fn null() -> Self
pub fn null() -> Self
Returns a pointer64 with a value of zero.
Examples
use memflow::types::Pointer64;
println!("pointer: {}", Pointer64::<()>::null());sourcepub fn is_null(self) -> bool
pub fn is_null(self) -> bool
Returns true if the pointer64 is null.
Examples
use memflow::types::Pointer32;
let ptr = Pointer32::<()>::from(0x1000u32);
assert!(!ptr.is_null());sourcepub fn non_null(self) -> Option<Pointer<U, T>>
pub fn non_null(self) -> Option<Pointer<U, T>>
Converts the pointer64 to an Option that is None when it is null
Examples
use memflow::types::Pointer64;
assert_eq!(Pointer64::<()>::null().non_null(), None);
assert_eq!(Pointer64::<()>::from(0x1000u64).non_null(), Some(Pointer64::from(0x1000u64)));sourcepub fn to_umem(self) -> umem
pub fn to_umem(self) -> umem
Converts the pointer into a raw umem value.
Examples
use memflow::types::{Pointer64, umem};
let ptr = Pointer64::<()>::from(0x1000u64);
let ptr_umem: umem = ptr.to_umem();
assert_eq!(ptr_umem, 0x1000);pub fn address(&self) -> Address
sourceimpl<U: PrimitiveAddress, T: Sized> Pointer<U, T>
impl<U: PrimitiveAddress, T: Sized> Pointer<U, T>
sourcepub fn offset(self, count: imem) -> Self
pub fn offset(self, count: imem) -> Self
Calculates the offset from a pointer64
count is in units of T; e.g., a count of 3 represents a pointer offset of 3 * size_of::<T>() bytes.
Panics
This function panics if T is a Zero-Sized Type (“ZST”).
This function also panics when offset * size_of::<T>()
causes overflow of a signed 64-bit integer.
Examples:
use memflow::types::Pointer64;
let ptr = Pointer64::<u16>::from(0x1000u64);
println!("{:?}", ptr.offset(3));sourcepub fn offset_from(self, origin: Self) -> imem
pub fn offset_from(self, origin: Self) -> imem
Calculates the distance between two pointers. The returned value is in
units of T: the distance in bytes is divided by mem::size_of::<T>().
This function is the inverse of offset.
Panics
This function panics if T is a Zero-Sized Type (“ZST”).
Examples:
use memflow::types::Pointer64;
let ptr1 = Pointer64::<u16>::from(0x1000u64);
let ptr2 = Pointer64::<u16>::from(0x1008u64);
assert_eq!(ptr2.offset_from(ptr1), 4);
assert_eq!(ptr1.offset_from(ptr2), -4);sourcepub fn add(self, count: umem) -> Self
pub fn add(self, count: umem) -> Self
Calculates the offset from a pointer (convenience for .offset(count as i64)).
count is in units of T; e.g., a count of 3 represents a pointer
offset of 3 * size_of::<T>() bytes.
Panics
This function panics if T is a Zero-Sized Type (“ZST”).
Examples
Basic usage:
use memflow::types::Pointer64;
let ptr = Pointer64::<u16>::from(0x1000u64);
println!("{:?}", ptr.add(3));sourcepub fn sub(self, count: umem) -> Self
pub fn sub(self, count: umem) -> Self
Calculates the offset from a pointer (convenience for
.offset((count as isize).wrapping_neg())).
count is in units of T; e.g., a count of 3 represents a pointer
offset of 3 * size_of::<T>() bytes.
Panics
This function panics if T is a Zero-Sized Type (“ZST”).
Examples
Basic usage:
use memflow::types::Pointer64;
let ptr = Pointer64::<u16>::from(0x1000u64);
println!("{:?}", ptr.sub(3));sourceimpl<U: PrimitiveAddress, T: Pod + ?Sized> Pointer<U, T>
impl<U: PrimitiveAddress, T: Pod + ?Sized> Pointer<U, T>
Implement special phys/virt read/write for Pod types
pub fn read_into<M: MemoryView>(
self,
mem: &mut M,
out: &mut T
) -> PartialResult<()>
sourceimpl<U: PrimitiveAddress, T: Pod + Sized> Pointer<U, T>
impl<U: PrimitiveAddress, T: Pod + Sized> Pointer<U, T>
pub fn read<M: MemoryView>(self, mem: &mut M) -> PartialResult<T>
pub fn write<M: MemoryView>(self, mem: &mut M, data: &T) -> PartialResult<()>
sourceimpl<U: PrimitiveAddress> Pointer<U, ReprCString>
impl<U: PrimitiveAddress> Pointer<U, ReprCString>
Implement special phys/virt read/write for CReprStr
pub fn read_string<M: MemoryView>(
self,
mem: &mut M
) -> PartialResult<ReprCString>
sourceimpl<U: PrimitiveAddress, T> Pointer<U, [T]>
impl<U: PrimitiveAddress, T> Pointer<U, [T]>